Class: Google::Cloud::Security::PrivateCA::V1beta1::Certificate
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1beta1::Certificate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1beta1/resources.rb
Overview
A Certificate corresponds to a signed X.509 certificate issued by a CertificateAuthority.
Defined Under Namespace
Classes: LabelsEntry, RevocationDetails
Instance Attribute Summary collapse
-
#certificate_description ⇒ ::Google::Cloud::Security::PrivateCA::V1beta1::CertificateDescription
readonly
Output only.
-
#config ⇒ ::Google::Cloud::Security::PrivateCA::V1beta1::CertificateConfig
Immutable.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#lifetime ⇒ ::Google::Protobuf::Duration
Required.
-
#name ⇒ ::String
readonly
Output only.
-
#pem_certificate ⇒ ::String
readonly
Output only.
-
#pem_certificate_chain ⇒ ::Array<::String>
readonly
Output only.
-
#pem_csr ⇒ ::String
Immutable.
-
#revocation_details ⇒ ::Google::Cloud::Security::PrivateCA::V1beta1::Certificate::RevocationDetails
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#certificate_description ⇒ ::Google::Cloud::Security::PrivateCA::V1beta1::CertificateDescription (readonly)
Returns Output only. A structured description of the issued X.509 certificate.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#config ⇒ ::Google::Cloud::Security::PrivateCA::V1beta1::CertificateConfig
Returns Immutable. A description of the certificate and key that does not require X.509 or ASN.1.
Note: The following fields are mutually exclusive: config, pem_csr. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this Certificate was created.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels with user-defined metadata.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#lifetime ⇒ ::Google::Protobuf::Duration
Returns Required. Immutable. The desired lifetime of a certificate. Used to create the "not_before_time" and "not_after_time" fields inside an X.509 certificate. Note that the lifetime may be truncated if it would extend past the life of any certificate authority in the issuing chain.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String (readonly)
Returns Output only. The resource path for this Certificate in the format
projects/*/locations/*/certificateAuthorities/*/certificates/*.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pem_certificate ⇒ ::String (readonly)
Returns Output only. The pem-encoded, signed X.509 certificate.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pem_certificate_chain ⇒ ::Array<::String> (readonly)
Returns Output only. The chain that may be used to verify the X.509 certificate. Expected to be in issuer-to-root order according to RFC 5246.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pem_csr ⇒ ::String
Returns Immutable. A pem-encoded X.509 certificate signing request (CSR).
Note: The following fields are mutually exclusive: pem_csr, config. If a field in that set is populated, all other fields in the set will automatically be cleared.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#revocation_details ⇒ ::Google::Cloud::Security::PrivateCA::V1beta1::Certificate::RevocationDetails (readonly)
Returns Output only. Details regarding the revocation of this Certificate. This Certificate is considered revoked if and only if this field is present.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this Certificate was updated.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 488 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1beta1::RevocationReason] # Indicates why a {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this {::Google::Cloud::Security::PrivateCA::V1beta1::Certificate Certificate} was revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |