Class: Google::Cloud::Security::PrivateCA::V1beta1::ReusableConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/security/privateca/v1beta1/resources.rb

Overview

A ReusableConfig refers to a managed ReusableConfigValues. Those, in turn, are used to describe certain fields of an X.509 certificate, such as the key usage fields, fields specific to CA certificates, certificate policy extensions and custom extensions.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which this ReusableConfig was created.

Returns:



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 538

class ReusableConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. A human-readable description of scenarios these ReusableConfigValues may be compatible with.

Returns:

  • (::String)

    Optional. A human-readable description of scenarios these ReusableConfigValues may be compatible with.



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 538

class ReusableConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels with user-defined metadata.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels with user-defined metadata.



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 538

class ReusableConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. The resource path for this ReusableConfig in the format projects/*/locations/*/reusableConfigs/*.

Returns:

  • (::String)

    Output only. The resource path for this ReusableConfig in the format projects/*/locations/*/reusableConfigs/*.



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 538

class ReusableConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which this ReusableConfig was updated.

Returns:



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 538

class ReusableConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#values::Google::Cloud::Security::PrivateCA::V1beta1::ReusableConfigValues

Returns Required. The config values.

Returns:



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'proto_docs/google/cloud/security/privateca/v1beta1/resources.rb', line 538

class ReusableConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end